@@ -6,7 +6,7 @@ use UNIVERSAL::require;
 sub register_method {
     +{
         'resultset_with_pager' => \&resultset_with_pager,
-    },
+    }
 }
 
 # see also DBIx::Skinny#resultset
@@ -38,6 +38,10 @@ DBIx::Skinny::Mixin::Pager
   my $rs = Proj::DB->resultset_with_pager('MySQLFoundRows');
   # $rs is DBIx::Skinny::Pager::Logic::MySQLFoundRows
 
+or
+
+  my ($iter, $pager) = Proj::DB->search_with_pager({ foo => "bar" }, { pager_logic => "PlusOne" });
+
 =head1 DESCRIPTION
 
 DBIx::Skinny::Mixin::Pager is a interface for mixin resultset_with_pager method to DBIx::Skinny.
